==> ukui-panel_4.10.3.1.orig.tar.gz: ukui-panel-4.10.3.1/widgets/ukui-menu-starter/i18n/org.ukui.menu.starter_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>StartMenuButton</name>
    <message>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Time Shutdown</source>
        <translation>定时关机</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Start Menu</source>
        <translation>开始菜单</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>系统设置</translation>
    </message>
    <message>
        <source>Power Options</source>
        <translation>电源选项</translation>
    </message>
    <message>
        <source>System Monitor</source>
        <translation>系统监视器</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>显示桌面</translation>
    </message>
    <message>
        <source>All Applications</source>
        <translation>全部应用</translation>
    </message>
    <message>
        <source>Power Manager</source>
        <translation>电源管理</translation>
    </message>
    <message>
        <source>About This Computer</source>
        <translation>关于本机</translation>
    </message>
    <message>
        <source>Network Settings</source>
        <translation>网络设置</translation>
    </message>
    <message>
        <source>Open Terminal</source>
        <translation>打开终端</translation>
    </message>
    <message>
        <source>Switch User or Log Out</source>
        <translation>切换账户或注销</translation>
    </message>
</context>
</TS>

==> ukui-panel_4.20.6.0.orig.tar.gz: ukui-panel-4.20.6.0/widgets/ukui-menu-starter/i18n/org.ukui.menu.starter_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>StartMenuButton</name>
    <message>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Time Shutdown</source>
        <translation>定时关机</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>系统设置</translation>
    </message>
    <message>
        <source>Power Options</source>
        <translation>电源选项</translation>
    </message>
    <message>
        <source>System Monitor</source>
        <translation>系统监视器</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>显示桌面</translation>
    </message>
    <message>
        <source>All Applications</source>
        <translation>全部应用</translation>
    </message>
    <message>
        <source>Power Manager</source>
        <translation>电源管理</translation>
    </message>
    <message>
        <source>About This Computer</source>
        <translation>关于本机</translation>
    </message>
    <message>
        <source>Network Settings</source>
        <translation>网络设置</translation>
    </message>
    <message>
        <source>Open Terminal</source>
        <translation>打开终端</translation>
    </message>
    <message>
        <source>Switch User or Log Out</source>
        <translation>切换用户或注销</translation>
    </message>
</context>
</TS>
